
--[[

name:   Antix Splash Screen
vers:   1.0.2
desc:   A simple splash screen with a logo that starts small, 
        zooms in until it is  full size, waits  for a second, 
        then  zooms out by  growing in size and  fading away. 
        Each phase is accompanied  by a strange sound sample.
auth:   by Cliff Earl, Antix Software
date:   June 2016
legal:  Distribute freely but please leave my credits intact.
histo:  v1.0.1
        Added  the  ability to  skip  the  splash  screen  by 
        touching the display if the global variable debugging 
        is true (see first line of init())
        v1.0.2
        Sound output now takes into account PREFS.soundVolume

--]]

Antix = Core.class(Sprite)

function Antix:init(userData) -- GoGo
  
  self.debugging = DEBUGGING -- SET TO FALSE IN PRODUCTION MODE!!!
  
  self.onComplete = userData.onComplete
  
  local width, height = application:getContentWidth(), application:getContentHeight()
  
  self.enterSound = Sound.new("antix/enter.wav") -- Funky sounds
  self.exitSound = Sound.new("antix/leave.wav")
  self.channel = nil

  local logo = Bitmap.new(Texture.new("antix/logo.png", true) )
  logo:setAnchorPoint(0.5, 0.5)
  
  local destX = width + logo:getWidth()
  
  logo:setPosition(width + logo:getWidth(), height * 0.5) -- Place logo off screen to right
  self.ratio = width / logo:getWidth() -- Calculate scale
  self:addChild(logo)
  
  self.destX = width + logo:getWidth()
  self.ratio = 3555
  
  self.width = width
  
  self.phase = "enter"
  self.elapsed = 0
  self.speed = 1
  
  self:addEventListener("enterBegin", self.onTransitionInBegin, self)
  self:addEventListener("enterEnd", self.onTransitionInEnd, self)
  self:addEventListener("exitBegin", self.onTransitionOutBegin, self)
  self:addEventListener("exitEnd", self.onTransitionOutEnd, self)
end

function Antix:onTouch(e)
  self.onComplete()
--  SCENEMANAGER:changeScene("Game", 1, SceneManager.fade, easing.linear)
end

function Antix:onTransitionInEnd() -- Add listeners, start logic
  local prefs = PREFS
  print("enter volume =", 1 * prefs.soundVolume)
  self.channel = self.enterSound:play(1, 1.6)
  self.channel:setVolume(1 * prefs.soundVolume)
  self:addEventListener(Event.ENTER_FRAME, self.update, self)
end

function Antix:onTransitionInBegin() -- Initialize variables
  if self.debugging then
    self:addEventListener(Event.TOUCHES_BEGIN, self.onTouch, self)
  end
end

function Antix:onTransitionOutBegin() -- Stoip Timers, remove listeners
  if self.debugging then
    self:removeEventListener(Event.TOUCHES_BEGIN, self.onTouch, self)
  end
  self:removeEventListener(Event.ENTER_FRAME, self.update, self)
end

function Antix:onTransitionOutEnd() -- Gone from stage, so cleanup
  self:removeEventListener("enterBegin", self.onTransitionInBegin, self)
  self:removeEventListener("enterEnd", self.onTransitionInEnd, self)
  self:removeEventListener("exitBegin", self.onTransitionOutBegin, self)
  self:removeEventListener("exitEnd", self.onTransitionOutEnd, self)
  
  local logo = self:getChildAt(1)
  logo:removeFromParent()
  logo = nil
  
  self.elapsed = nil
  self.speed = nil
  
  if self.channel then self.channel:stop() end
  self.channel = nil
  self.enterSound = nil
  self.exitSound = nil
end

-- Update every frame
function Antix:update(e)
  local elapsed = self.elapsed + (e.deltaTime * self.speed)
  
  local logo = self:getChildAt(1)
  
  local phase = self.phase
  
  if phase == "enter" then -- Zoom in until full size
    logo:setRotation(self.ratio * elapsed)
    logo:setX(self.destX - ((self.destX - (self.width * 0.5)) * elapsed))
    if elapsed >= 1 then
      self.channel:stop()
      self.phase = "wait"
    end
    
  elseif phase == "wait" then -- Wait a bit (1.5 seconds to be exact)
    if elapsed >= 2.5 then
      local prefs = PREFS
      self.channel = self.exitSound:play()
      self.channel:setVolume(1 * prefs.soundVolume)
      self.ratio = 1
      self.phase = "leave"
    end
    
  else -- Must be leaving if we arrived here
    self.speed = self.speed + 2
    local alpha = logo:getAlpha() - 0.018
    if alpha <= 0 then
      
    self.onComplete() -- execute onComplete function
    
    else
      logo:setAlpha(alpha)
      logo:setScale(self.ratio * (elapsed - 1.5) )
    end
  end
  
  self.elapsed = elapsed
end
